<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 ********************************************************************************/

$mod_strings = Array(
    'LBL_MODULE_NAME' => 'Administration',
    'LBL_MODULE_TITLE' => 'Administration: Home',

    'LBL_NEW_FORM_TITLE' => 'neuer Benutzer',
    'ERR_DELETE_RECORD' => 'Zum Löschen muss mindestens ein Benutzer ausgewählt werden.',
);

?>